﻿// --------------------------------------------------------------------------------------
//
// SortierAnlage.cs                                               Ulrich Müller   2.02.08
//                                                                PCS1700 C# 2005 Express
// Sortieranlage aus Experimentierbuch Profi Computing 36 069 von 1991
// MainThread enthält die Initialisierung und die Bandsteuerung nach Größe
// Der Thread Vereinzler übernimmt die Vereinzlung der Teile
//     Basis ist die Assembly FishFace2005.DLL
//
// --------------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using FishFace40;

namespace SortierAnlage {
  public partial class frmSortMain : Form {
    private const Out mSortBand        = Out.M1;
    private const Inp eBandImpuls      = Inp.I5;
    private const Out mTranportBand    = Out.M2;
    private const Inp eLSchrankeHoch   = Inp.I3;
    private const Inp eLSchrankeNieder = Inp.I4;
    private const Out mSchieber        = Out.M3;
    private const Inp eSchieberVorn    = Inp.I1;
    private const Inp eSchieberHintenF = Inp.I2;
    private const Out mLSchrankeLampe  = Out.M4;

    FishFace ft = new FishFace();
    Thread ve;

    private void Action() {
      ft.SetMotor(mLSchrankeLampe, Dir.Ein);
      ft.Pause(1000);
      ft.SetMotor(mTranportBand, Dir.Links, Speed.Half);
      ve = new Thread(new ThreadStart(Vereinzler));
      ve.IsBackground = true;
      ve.Start();
      do {
        if (!ft.GetInput(eLSchrankeHoch)) {
          ft.SetMotor(mSortBand, Dir.Rechts);
          ft.WaitForChange(eBandImpuls, 20);
          ft.SetMotor(mSortBand, Dir.Aus);
        }
        else if (!ft.GetInput(eLSchrankeNieder)) {
          ft.SetMotor(mSortBand, Dir.Links);
          ft.WaitForChange(eBandImpuls, 20);
          ft.SetMotor(mSortBand, Dir.Aus);
        }
      } while (!ft.Finish());

    }
    private void Vereinzler() {
      do {
        ft.SetMotor(mSchieber, Dir.Rechts);
        ft.WaitForInput(eSchieberHintenF, false);
        ft.SetMotor(mSchieber, Dir.Links);
        ft.WaitForInput(eSchieberVorn);
        ft.SetMotor(mSchieber, Dir.Aus);
        ft.WaitForInput(eLSchrankeNieder, false);
      } while (!ft.Finish());
    }

    #region --- Programm-Kontrolle ---
    public frmSortMain() {
      InitializeComponent();
    }

    private void cmdAction_Click(object sender, EventArgs e) {
      // --- Open erstes ROBO an USB oder Intelligent Interface an COM
      //     während des Ablaufs von Action() gesperrt ---------------
      try {
        if (cboPortName.SelectedIndex == 0)
          ft.OpenInterface(IFTypen.ftROBO_first_USB, 0);
        else ft.OpenInterface(IFTypen.ftIntelligent_IF, cboPortName.SelectedIndex, 5);
        cmdAction.Enabled = false;
        cmdEnde.Text = "&HALT";
        lblStatus.Text = "--- Bei der Arbeit ---";
        lblHinweis.Text = "--- Ende : HALT-Button oder ESC-Taste ---";

        Action();        // --- Haupt-Routine der Anwendung

        ft.ClearMotors();
      }
      catch (FishFaceException eft) {
        MessageBox.Show(eft.Message, this.Text,
          MessageBoxButtons.OK, MessageBoxIcon.Stop);
      }
      finally {
        ft.CloseInterface();
        cmdAction.Enabled = true;
        cmdEnde.Text = "&ENDE";
        lblStatus.Text = "--- Auf ein Neues ---";
        lblHinweis.Text = "Nochmal : ACTION, sonst ENDE oder ESC-Taste";
        cmdAction.Focus();
      }
    }

    private void cmdEnde_Click(object sender, EventArgs e) {
      // --- Programmende nur, wenn Action nicht läuft ---
      if (cmdEnde.Text == "&HALT") ft.NotHalt = true; else this.Close();
    }

    private void formLoad(object sender, EventArgs e) {
      // --- Default-Interface : Erstes ROBO Interface an USB ----
      cboPortName.SelectedIndex = 0;
    }

    private void formClosing(object sender, FormClosingEventArgs e) {
      // --- Wenn Action läuft, wird ein Programmabbruch über (x) unterbunden ------
      if (cmdEnde.Text == "&HALT") e.Cancel = true;
    }
    #endregion
  }
}